-- 股票元数据表定义
CREATE TABLE IF NOT EXISTS stock_metadata (
    ts_code VARCHAR(10) PRIMARY KEY COMMENT '股票代码',
    symbol VARCHAR(10) COMMENT '股票代码（不含交易所）',
    name VARCHAR(50) COMMENT '股票名称',
    area VARCHAR(20) COMMENT '地域',
    industry VARCHAR(20) COMMENT '所属行业',
    fullname VARCHAR(100) COMMENT '股票全称',
    enname VARCHAR(200) COMMENT '英文全称',
    cnspell VARCHAR(20) COMMENT '拼音缩写',
    market VARCHAR(10) COMMENT '市场类型',
    exchange VARCHAR(10) COMMENT '交易所代码 SSE/SZSE/BSE',
    curr_type VARCHAR(10) COMMENT '交易货币',
    list_status VARCHAR(2) COMMENT '上市状态 L上市 D退市 P暂停上市',
    list_date DATE COMMENT '上市日期',
    delist_date DATE COMMENT '退市日期',
    is_hs VARCHAR(1) COMMENT '是否沪深港通标的，N否 H沪股通 S深股通',
    act_name VARCHAR(50) COMMENT '实际控制人名称',
    act_ent_type VARCHAR(30) COMMENT '实际控制人企业性质',
    -- 数据管理相关字段
    last_full_update TIMESTAMP NULL DEFAULT NULL COMMENT '最后一次全量更新时间',
    last_incremental_update TIMESTAMP NULL DEFAULT NULL COMMENT '最后一次增量更新时间',
    data_start_date DATE DEFAULT NULL COMMENT 'daily数据开始日期',
    data_end_date DATE DEFAULT NULL COMMENT 'daily数据结束日期',
    record_count INT DEFAULT 0 COMMENT '记录总数',
    status TINYINT DEFAULT 0 COMMENT '数据状态: 0-未初始化, 1-正常, 2-异常',
    -- 最新交易日基本信息（便于快速访问）
    latest_price DECIMAL(10,2) DEFAULT 0.00 COMMENT '最新收盘价',
    latest_date DATE DEFAULT NULL COMMENT '最新交易日期',
    latest_pe_ttm DECIMAL(10,4) DEFAULT 0.0000 COMMENT '最新市盈率(TTM)',
    latest_pb DECIMAL(10,4) DEFAULT 0.0000 COMMENT '最新市净率',
    latest_total_mv DECIMAL(20,4) DEFAULT 0.0000 COMMENT '最新总市值(万元)',
    remark VARCHAR(500) DEFAULT '自动导入' COMMENT '备注信息',
    create_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    update_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX idx_status (status),
    INDEX idx_industry (industry),
    INDEX idx_market (market),
    INDEX idx_exchange (exchange),
    INDEX idx_latest_date (latest_date)
) ENGINE=InnoDB COMMENT '股票数据元信息表';