CREATE TABLE IF NOT EXISTS `{symbol}` (
    trade_date DATE PRIMARY KEY COMMENT '交易日期',

    -- daily价格数据
    open DECIMAL(10,2) COMMENT '开盘价',
    high DECIMAL(10,2) COMMENT '最高价',
    low DECIMAL(10,2) COMMENT '最低价',
    close DECIMAL(10,2) COMMENT '收盘价',
    pre_close DECIMAL(10,2) COMMENT '昨收价',
    change_val DECIMAL(10,2) COMMENT '涨跌额',
    pct_chg DECIMAL(10,4) COMMENT '涨跌幅',
    vol DECIMAL(20,2) COMMENT '成交量',
    amount DECIMAL(20,2) COMMENT '成交额',

    -- daily_basic基础指标
    turnover_rate DECIMAL(10,4) COMMENT '换手率',
    turnover_rate_f DECIMAL(10,4) COMMENT '换手率(自由流通股本)',
    volume_ratio DECIMAL(10,2) COMMENT '量比',
    pe DECIMAL(10,4) COMMENT '市盈率',
    pe_ttm DECIMAL(10,4) COMMENT '市盈率(TTM)',
    pb DECIMAL(10,4) COMMENT '市净率',
    ps DECIMAL(10,4) COMMENT '市销率',
    ps_ttm DECIMAL(10,4) COMMENT '市销率(TTM)',
    dv_ratio DECIMAL(10,4) COMMENT '股息率',
    dv_ttm DECIMAL(10,4) COMMENT '股息率(TTM)',
    total_share DECIMAL(20,4) COMMENT '总股本(万股)',
    float_share DECIMAL(20,4) COMMENT '流通股本(万股)',
    free_share DECIMAL(20,4) COMMENT '自由流通股本(万股)',
    total_mv DECIMAL(20,4) COMMENT '总市值(万元)',
    circ_mv DECIMAL(20,4) COMMENT '流通市值(万元)',

    -- moneyflow资金流向
    buy_sm_vol DECIMAL(20,2) COMMENT '小单买入量(手)',
    buy_sm_amount DECIMAL(20,2) COMMENT '小单买入金额(万元)',
    sell_sm_vol DECIMAL(20,2) COMMENT '小单卖出量(手)',
    sell_sm_amount DECIMAL(20,2) COMMENT '小单卖出金额(万元)',
    buy_md_vol DECIMAL(20,2) COMMENT '中单买入量(手)',
    buy_md_amount DECIMAL(20,2) COMMENT '中单买入金额(万元)',
    sell_md_vol DECIMAL(20,2) COMMENT '中单卖出量(手)',
    sell_md_amount DECIMAL(20,2) COMMENT '中单卖出金额(万元)',
    buy_lg_vol DECIMAL(20,2) COMMENT '大单买入量(手)',
    buy_lg_amount DECIMAL(20,2) COMMENT '大单买入金额(万元)',
    sell_lg_vol DECIMAL(20,2) COMMENT '大单卖出量(手)',
    sell_lg_amount DECIMAL(20,2) COMMENT '大单卖出金额(万元)',
    buy_elg_vol DECIMAL(20,2) COMMENT '特大单买入量(手)',
    buy_elg_amount DECIMAL(20,2) COMMENT '特大单买入金额(万元)',
    sell_elg_vol DECIMAL(20,2) COMMENT '特大单卖出量(手)',
    sell_elg_amount DECIMAL(20,2) COMMENT '特大单卖出金额(万元)',
    net_mf_vol DECIMAL(20,2) COMMENT '净流入量(手)',
    net_mf_amount DECIMAL(20,2) COMMENT '净流入额(万元)',

    update_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',

    INDEX idx_date (trade_date)
) ENGINE=InnoDB COMMENT '{symbol}股票所有交易数据';